==> lxqt-panel-2.0.0.tar.xz: lxqt-panel-2.0.0/plugin-fancymenu/translations/fancymenu_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_RS">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Прикажи/сакриј мени</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="55"/>
        <source>All Applications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Опште</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Икона:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Текст дугмета:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Прилагођена величина фонта:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Фајл менија</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Фајл менија:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Пречица тастатуре</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Кликните на дугме да снимите пречицу:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Обриши претрагу по приказу менија</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Ресет</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Изабери икону фајла</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Слике (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Изабери фајл менија</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Фајлови менија (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="153"/>
        <source>Search...</source>
        <translation>Претражи...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="160"/>
        <source>LXQt Configuration Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="166"/>
        <source>Leave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="172"/>
        <source>About LXQt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="185"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="345"/>
        <source>Add to desktop</source>
        <translation>Додај на десктоп</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="353"/>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="354"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Фајл са истим именом већ постоји.
Желиш ли да га препишеш?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="360"/>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="361"/>
        <source>The file cannot be overwritten.</source>
        <translation>Овај фајл не може бити преписан.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="368"/>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="381"/>
        <source>Remove from Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="388"/>
        <source>Add to Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="572"/>
        <source>No Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="573"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.1.1.tar.xz: lxqt-panel-2.1.1/plugin-fancymenu/translations/fancymenu_sr_RS.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_RS">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Прикажи/сакриј мени</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="56"/>
        <source>All Applications</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Опште</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Икона:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Текст дугмета:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Прилагођена величина фонта:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Фајл менија</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Фајл менија:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>Пречица тастатуре</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Кликните на дугме да снимите пречицу:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Претражи</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Обриши претрагу по приказу менија</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Ресет</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Изабери икону фајла</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Слике (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Изабери фајл менија</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Фајлови менија (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation>Претражи...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="191"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="357"/>
        <source>Add to desktop</source>
        <translation>Додај на десктоп</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="365"/>
        <source>Question</source>
        <translation>Питање</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="366"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Фајл са истим именом већ постоји.
Желиш ли да га препишеш?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="372"/>
        <source>Warning</source>
        <translation>Упозорење</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="373"/>
        <source>The file cannot be overwritten.</source>
        <translation>Овај фајл не може бити преписан.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="380"/>
        <source>Copy</source>
        <translation>Копирај</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="393"/>
        <source>Remove from Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="400"/>
        <source>Add to Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="716"/>
        <source>No Executable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="717"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
